from typing import Any, Dict, Iterable, Optional, Sequence, Tuple, Type, Union

from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    retry as retries,
)
from google.auth import credentials

from google.ads.googleads.v7.services.services.google_ads_service import pagers
from google.ads.googleads.v7.services.types import google_ads_service

from .transports.base import GoogleAdsServiceTransport

class GoogleAdsServiceClientMeta(type):
    def get_transport_class(
        cls, label: str = ...
    ) -> Type[GoogleAdsServiceTransport]: ...

class GoogleAdsServiceClient(metaclass=GoogleAdsServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Any
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json: Any
    @property
    def transport(self) -> GoogleAdsServiceTransport: ...
    @staticmethod
    def account_budget_path(customer_id: str, account_budget_id: str) -> str: ...
    @staticmethod
    def parse_account_budget_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def account_budget_proposal_path(
        customer_id: str, account_budget_proposal_id: str
    ) -> str: ...
    @staticmethod
    def parse_account_budget_proposal_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def account_link_path(customer_id: str, account_link_id: str) -> str: ...
    @staticmethod
    def parse_account_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_path(customer_id: str, ad_id: str) -> str: ...
    @staticmethod
    def parse_ad_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_path(customer_id: str, ad_group_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_ad_path(customer_id: str, ad_group_id: str, ad_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_ad_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_ad_asset_view_path(
        customer_id: str, ad_group_id: str, ad_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_ad_asset_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_ad_label_path(
        customer_id: str, ad_group_id: str, ad_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_ad_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_asset_path(
        customer_id: str, ad_group_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_audience_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_audience_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_bid_modifier_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_bid_modifier_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_criterion_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_criterion_label_path(
        customer_id: str, ad_group_id: str, criterion_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_criterion_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_criterion_simulation_path(
        customer_id: str,
        ad_group_id: str,
        criterion_id: str,
        type: str,
        modification_method: str,
        start_date: str,
        end_date: str,
    ) -> str: ...
    @staticmethod
    def parse_ad_group_criterion_simulation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_extension_setting_path(
        customer_id: str, ad_group_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_feed_path(customer_id: str, ad_group_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_label_path(
        customer_id: str, ad_group_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_simulation_path(
        customer_id: str,
        ad_group_id: str,
        type: str,
        modification_method: str,
        start_date: str,
        end_date: str,
    ) -> str: ...
    @staticmethod
    def parse_ad_group_simulation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_parameter_path(
        customer_id: str, ad_group_id: str, criterion_id: str, parameter_index: str
    ) -> str: ...
    @staticmethod
    def parse_ad_parameter_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_schedule_view_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_schedule_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def age_range_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_age_range_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def asset_path(customer_id: str, asset_id: str) -> str: ...
    @staticmethod
    def parse_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def batch_job_path(customer_id: str, batch_job_id: str) -> str: ...
    @staticmethod
    def parse_batch_job_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def bidding_strategy_path(customer_id: str, bidding_strategy_id: str) -> str: ...
    @staticmethod
    def parse_bidding_strategy_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def bidding_strategy_simulation_path(
        customer_id: str,
        bidding_strategy_id: str,
        type: str,
        modification_method: str,
        start_date: str,
        end_date: str,
    ) -> str: ...
    @staticmethod
    def parse_bidding_strategy_simulation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def billing_setup_path(customer_id: str, billing_setup_id: str) -> str: ...
    @staticmethod
    def parse_billing_setup_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def call_view_path(customer_id: str, call_detail_id: str) -> str: ...
    @staticmethod
    def parse_call_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_path(customer_id: str, campaign_id: str) -> str: ...
    @staticmethod
    def parse_campaign_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_asset_path(
        customer_id: str, campaign_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_audience_view_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_audience_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_bid_modifier_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_bid_modifier_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_budget_path(customer_id: str, campaign_budget_id: str) -> str: ...
    @staticmethod
    def parse_campaign_budget_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_criterion_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_criterion_simulation_path(
        customer_id: str,
        campaign_id: str,
        criterion_id: str,
        type: str,
        modification_method: str,
        start_date: str,
        end_date: str,
    ) -> str: ...
    @staticmethod
    def parse_campaign_criterion_simulation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_draft_path(
        customer_id: str, base_campaign_id: str, draft_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_draft_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_experiment_path(
        customer_id: str, campaign_experiment_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_experiment_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_extension_setting_path(
        customer_id: str, campaign_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_feed_path(customer_id: str, campaign_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_campaign_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_label_path(
        customer_id: str, campaign_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_shared_set_path(
        customer_id: str, campaign_id: str, shared_set_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_shared_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_simulation_path(
        customer_id: str,
        campaign_id: str,
        type: str,
        modification_method: str,
        start_date: str,
        end_date: str,
    ) -> str: ...
    @staticmethod
    def parse_campaign_simulation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def carrier_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_carrier_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def change_event_path(
        customer_id: str, timestamp_micros: str, command_index: str, mutate_index: str
    ) -> str: ...
    @staticmethod
    def parse_change_event_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def change_status_path(customer_id: str, change_status_id: str) -> str: ...
    @staticmethod
    def parse_change_status_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def click_view_path(customer_id: str, date: str, gclid: str) -> str: ...
    @staticmethod
    def parse_click_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def combined_audience_path(customer_id: str, combined_audience_id: str) -> str: ...
    @staticmethod
    def parse_combined_audience_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def conversion_action_path(customer_id: str, conversion_action_id: str) -> str: ...
    @staticmethod
    def parse_conversion_action_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def conversion_custom_variable_path(
        customer_id: str, conversion_custom_variable_id: str
    ) -> str: ...
    @staticmethod
    def parse_conversion_custom_variable_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def currency_constant_path(code: str) -> str: ...
    @staticmethod
    def parse_currency_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def custom_audience_path(customer_id: str, custom_audience_id: str) -> str: ...
    @staticmethod
    def parse_custom_audience_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_path(customer_id: str) -> str: ...
    @staticmethod
    def parse_customer_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_asset_path(
        customer_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_customer_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_client_path(customer_id: str, client_customer_id: str) -> str: ...
    @staticmethod
    def parse_customer_client_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_client_link_path(
        customer_id: str, client_customer_id: str, manager_link_id: str
    ) -> str: ...
    @staticmethod
    def parse_customer_client_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_extension_setting_path(
        customer_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_customer_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_feed_path(customer_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_customer_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_label_path(customer_id: str, label_id: str) -> str: ...
    @staticmethod
    def parse_customer_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_manager_link_path(
        customer_id: str, manager_customer_id: str, manager_link_id: str
    ) -> str: ...
    @staticmethod
    def parse_customer_manager_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_negative_criterion_path(
        customer_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_customer_negative_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_user_access_path(customer_id: str, user_id: str) -> str: ...
    @staticmethod
    def parse_customer_user_access_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_user_access_invitation_path(
        customer_id: str, invitation_id: str
    ) -> str: ...
    @staticmethod
    def parse_customer_user_access_invitation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def custom_interest_path(customer_id: str, custom_interest_id: str) -> str: ...
    @staticmethod
    def parse_custom_interest_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def detail_placement_view_path(
        customer_id: str, ad_group_id: str, base64_placement: str
    ) -> str: ...
    @staticmethod
    def parse_detail_placement_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def display_keyword_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_display_keyword_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def distance_view_path(
        customer_id: str, placeholder_chain_id: str, distance_bucket: str
    ) -> str: ...
    @staticmethod
    def parse_distance_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def domain_category_path(
        customer_id: str, campaign_id: str, base64_category: str, language_code: str
    ) -> str: ...
    @staticmethod
    def parse_domain_category_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def dynamic_search_ads_search_term_view_path(
        customer_id: str,
        ad_group_id: str,
        search_term_fingerprint: str,
        headline_fingerprint: str,
        landing_page_fingerprint: str,
        page_url_fingerprint: str,
    ) -> str: ...
    @staticmethod
    def parse_dynamic_search_ads_search_term_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def expanded_landing_page_view_path(
        customer_id: str, expanded_final_url_fingerprint: str
    ) -> str: ...
    @staticmethod
    def parse_expanded_landing_page_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def extension_feed_item_path(customer_id: str, feed_item_id: str) -> str: ...
    @staticmethod
    def parse_extension_feed_item_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_path(customer_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_path(customer_id: str, feed_id: str, feed_item_id: str) -> str: ...
    @staticmethod
    def parse_feed_item_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_set_path(
        customer_id: str, feed_id: str, feed_item_set_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_item_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_set_link_path(
        customer_id: str, feed_id: str, feed_item_set_id: str, feed_item_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_item_set_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_target_path(
        customer_id: str,
        feed_id: str,
        feed_item_id: str,
        feed_item_target_type: str,
        feed_item_target_id: str,
    ) -> str: ...
    @staticmethod
    def parse_feed_item_target_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_mapping_path(
        customer_id: str, feed_id: str, feed_mapping_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_mapping_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_placeholder_view_path(customer_id: str, placeholder_type: str) -> str: ...
    @staticmethod
    def parse_feed_placeholder_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def gender_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_gender_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def geographic_view_path(
        customer_id: str, country_criterion_id: str, location_type: str
    ) -> str: ...
    @staticmethod
    def parse_geographic_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def geo_target_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_geo_target_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def group_placement_view_path(
        customer_id: str, ad_group_id: str, base64_placement: str
    ) -> str: ...
    @staticmethod
    def parse_group_placement_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def hotel_group_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_hotel_group_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def hotel_performance_view_path(customer_id: str) -> str: ...
    @staticmethod
    def parse_hotel_performance_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def income_range_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_income_range_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_path(customer_id: str, keyword_plan_id: str) -> str: ...
    @staticmethod
    def parse_keyword_plan_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_ad_group_path(
        customer_id: str, keyword_plan_ad_group_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_ad_group_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_ad_group_keyword_path(
        customer_id: str, keyword_plan_ad_group_keyword_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_ad_group_keyword_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_campaign_path(
        customer_id: str, keyword_plan_campaign_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_campaign_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_campaign_keyword_path(
        customer_id: str, keyword_plan_campaign_keyword_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_campaign_keyword_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def label_path(customer_id: str, label_id: str) -> str: ...
    @staticmethod
    def parse_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def landing_page_view_path(
        customer_id: str, unexpanded_final_url_fingerprint: str
    ) -> str: ...
    @staticmethod
    def parse_landing_page_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def language_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_language_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def life_event_path(customer_id: str, life_event_id: str) -> str: ...
    @staticmethod
    def parse_life_event_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def location_view_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_location_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def managed_placement_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_managed_placement_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def media_file_path(customer_id: str, media_file_id: str) -> str: ...
    @staticmethod
    def parse_media_file_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def mobile_app_category_constant_path(mobile_app_category_id: str) -> str: ...
    @staticmethod
    def parse_mobile_app_category_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def mobile_device_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_mobile_device_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def offline_user_data_job_path(
        customer_id: str, offline_user_data_update_id: str
    ) -> str: ...
    @staticmethod
    def parse_offline_user_data_job_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def operating_system_version_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_operating_system_version_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def paid_organic_search_term_view_path(
        customer_id: str, campaign_id: str, ad_group_id: str, base64_search_term: str
    ) -> str: ...
    @staticmethod
    def parse_paid_organic_search_term_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def parental_status_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_parental_status_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def payments_account_path(customer_id: str, payments_account_id: str) -> str: ...
    @staticmethod
    def parse_payments_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def product_bidding_category_constant_path(
        country_code: str, level: str, id: str
    ) -> str: ...
    @staticmethod
    def parse_product_bidding_category_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def product_group_view_path(
        customer_id: str, adgroup_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_product_group_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def recommendation_path(customer_id: str, recommendation_id: str) -> str: ...
    @staticmethod
    def parse_recommendation_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def remarketing_action_path(
        customer_id: str, remarketing_action_id: str
    ) -> str: ...
    @staticmethod
    def parse_remarketing_action_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def search_term_view_path(
        customer_id: str, campaign_id: str, ad_group_id: str, query: str
    ) -> str: ...
    @staticmethod
    def parse_search_term_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def shared_criterion_path(
        customer_id: str, shared_set_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_shared_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def shared_set_path(customer_id: str, shared_set_id: str) -> str: ...
    @staticmethod
    def parse_shared_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def shopping_performance_view_path(customer_id: str) -> str: ...
    @staticmethod
    def parse_shopping_performance_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def third_party_app_analytics_link_path(
        customer_id: str, customer_link_id: str
    ) -> str: ...
    @staticmethod
    def parse_third_party_app_analytics_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def topic_constant_path(topic_id: str) -> str: ...
    @staticmethod
    def parse_topic_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def topic_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_topic_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def user_interest_path(customer_id: str, user_interest_id: str) -> str: ...
    @staticmethod
    def parse_user_interest_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def user_list_path(customer_id: str, user_list_id: str) -> str: ...
    @staticmethod
    def parse_user_list_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def user_location_view_path(
        customer_id: str, country_criterion_id: str, is_targeting_location: str
    ) -> str: ...
    @staticmethod
    def parse_user_location_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def video_path(customer_id: str, video_id: str) -> str: ...
    @staticmethod
    def parse_video_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def webpage_view_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_webpage_view_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> Dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: Optional[credentials.Credentials] = ...,
        transport: Union[str, GoogleAdsServiceTransport, None] = ...,
        client_options: Optional[client_options_lib.ClientOptions] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    def search(
        self,
        request: google_ads_service.SearchGoogleAdsRequest = ...,
        *,
        customer_id: str = ...,
        query: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> pagers.SearchPager: ...
    def search_stream(
        self,
        request: google_ads_service.SearchGoogleAdsStreamRequest = ...,
        *,
        customer_id: str = ...,
        query: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> Iterable[google_ads_service.SearchGoogleAdsStreamResponse]: ...
    def mutate(
        self,
        request: google_ads_service.MutateGoogleAdsRequest = ...,
        *,
        customer_id: str = ...,
        mutate_operations: Sequence[google_ads_service.MutateOperation] = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> google_ads_service.MutateGoogleAdsResponse: ...



from typing import Any

import proto

__protobuf__: Any

class CustomerManagerLinkErrorEnum(proto.Message):
    class CustomerManagerLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NO_PENDING_INVITE: int
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL: int
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS: int
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER: int
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER: int
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER: int
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT: int
        DUPLICATE_CHILD_FOUND: int
        TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS: int



from typing import Any

import proto

__protobuf__: Any

class AdGroupErrorEnum(proto.Message):
    class AdGroupError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_ADGROUP_NAME: int
        INVALID_ADGROUP_NAME: int
        ADVERTISER_NOT_ON_CONTENT_NETWORK: int
        BID_TOO_BIG: int
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH: int
        MISSING_ADGROUP_NAME: int
        ADGROUP_LABEL_DOES_NOT_EXIST: int
        ADGROUP_LABEL_ALREADY_EXISTS: int
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP: int
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE: int
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY: int
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING: int
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER: int
        INVALID_EXCLUDED_PARENT_ASSET_FIELD_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class FunctionErrorEnum(proto.Message):
    class FunctionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_FUNCTION_FORMAT: int
        DATA_TYPE_MISMATCH: int
        INVALID_CONJUNCTION_OPERANDS: int
        INVALID_NUMBER_OF_OPERANDS: int
        INVALID_OPERAND_TYPE: int
        INVALID_OPERATOR: int
        INVALID_REQUEST_CONTEXT_TYPE: int
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER: int
        INVALID_FUNCTION_FOR_PLACEHOLDER: int
        INVALID_OPERAND: int
        MISSING_CONSTANT_OPERAND_VALUE: int
        INVALID_CONSTANT_OPERAND_VALUE: int
        INVALID_NESTING: int
        MULTIPLE_FEED_IDS_NOT_SUPPORTED: int
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA: int
        INVALID_ATTRIBUTE_NAME: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import asset_field_type as asset_field_type

__protobuf__: Any

class AssetFieldTypeView(proto.Message):
    resource_name: Any
    field_type: Any



from typing import Any

import proto

__protobuf__: Any

class OfflineUserAddressInfo(proto.Message):
    hashed_first_name: Any
    hashed_last_name: Any
    city: Any
    state: Any
    country_code: Any
    postal_code: Any

class UserIdentifier(proto.Message):
    user_identifier_source: Any
    hashed_email: Any
    hashed_phone_number: Any
    mobile_id: Any
    third_party_user_id: Any
    address_info: Any

class TransactionAttribute(proto.Message):
    transaction_date_time: Any
    transaction_amount_micros: Any
    currency_code: Any
    conversion_action: Any
    order_id: Any
    store_attribute: Any
    custom_value: Any

class StoreAttribute(proto.Message):
    store_code: Any

class UserData(proto.Message):
    user_identifiers: Any
    transaction_attribute: Any
    user_attribute: Any

class UserAttribute(proto.Message):
    lifetime_value_micros: Any
    lifetime_value_bucket: Any

class CustomerMatchUserListMetadata(proto.Message):
    user_list: Any

class StoreSalesMetadata(proto.Message):
    loyalty_fraction: Any
    transaction_upload_fraction: Any
    custom_key: Any
    third_party_metadata: Any

class StoreSalesThirdPartyMetadata(proto.Message):
    advertiser_upload_date_time: Any
    valid_transaction_fraction: Any
    partner_match_fraction: Any
    partner_upload_fraction: Any
    bridge_map_version_id: Any
    partner_id: Any



from typing import Any

import proto

__protobuf__: Any

class CountryCodeErrorEnum(proto.Message):
    class CountryCodeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_COUNTRY_CODE: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import campaign_asset as campaign_asset

__protobuf__: Any

class GetCampaignAssetRequest(proto.Message):
    resource_name: Any

class MutateCampaignAssetsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class CampaignAssetOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateCampaignAssetsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCampaignAssetResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import mobile_device_type as mobile_device_type

__protobuf__: Any

class MobileDeviceConstant(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    manufacturer_name: Any
    operating_system_name: Any
    type_: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    billing_setup_status as billing_setup_status,
    time_type as time_type,
)

__protobuf__: Any

class BillingSetup(proto.Message):
    class PaymentsAccountInfo(proto.Message):
        payments_account_id: Any
        payments_account_name: Any
        payments_profile_id: Any
        payments_profile_name: Any
        secondary_payments_profile_id: Any
    resource_name: Any
    id: Any
    status: Any
    payments_account: Any
    payments_account_info: Any
    start_date_time: Any
    start_time_type: Any
    end_date_time: Any
    end_time_type: Any



from typing import Any

import proto

__protobuf__: Any

class ContextErrorEnum(proto.Message):
    class ContextError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPERATION_NOT_PERMITTED_FOR_CONTEXT: int
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE: int



from typing import Any

import proto

__protobuf__: Any

class ExtensionFeedItemErrorEnum(proto.Message):
    class ExtensionFeedItemError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        VALUE_OUT_OF_RANGE: int
        URL_LIST_TOO_LONG: int
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING: int
        CANNOT_SET_WITH_FINAL_URLS: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        INVALID_PHONE_NUMBER: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_CALL_CONVERSION_ACTION: int
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_CALLTRACKING: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        INVALID_APP_ID: int
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int
        REVIEW_EXTENSION_SOURCE_INELIGIBLE: int
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int
        INCONSISTENT_CURRENCY_CODES: int
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS: int
        UNSUPPORTED_VALUE: int
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE: int
        INVALID_DEVICE_PREFERENCE: int
        INVALID_SCHEDULE_END: int
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int
        INVALID_SNIPPETS_HEADER: int
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM: int
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int
        CONFLICTING_CALL_CONVERSION_SETTINGS: int
        EXTENSION_TYPE_MISMATCH: int
        EXTENSION_SUBTYPE_REQUIRED: int
        EXTENSION_TYPE_UNSUPPORTED: int
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS: int
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES: int
        INVALID_PRICE_FORMAT: int
        PROMOTION_INVALID_TIME: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        CONCRETE_EXTENSION_TYPE_REQUIRED: int
        SCHEDULE_END_NOT_AFTER_START: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import criteria as criteria
from google.ads.googleads.v7.enums.types import (
    frequency_cap_time_unit as frequency_cap_time_unit,
    reach_plan_ad_length as reach_plan_ad_length,
    reach_plan_age_range as reach_plan_age_range,
    reach_plan_network as reach_plan_network,
)

__protobuf__: Any

class ListPlannableLocationsRequest(proto.Message): ...

class ListPlannableLocationsResponse(proto.Message):
    plannable_locations: Any

class PlannableLocation(proto.Message):
    id: Any
    name: Any
    parent_country_id: Any

class ListPlannableProductsRequest(proto.Message):
    plannable_location_id: Any

class ListPlannableProductsResponse(proto.Message):
    product_metadata: Any

class ProductMetadata(proto.Message):
    plannable_product_code: Any
    plannable_product_name: Any
    plannable_targeting: Any

class PlannableTargeting(proto.Message):
    age_ranges: Any
    genders: Any
    devices: Any
    networks: Any

class GenerateProductMixIdeasRequest(proto.Message):
    customer_id: Any
    plannable_location_id: Any
    currency_code: Any
    budget_micros: Any
    preferences: Any

class Preferences(proto.Message):
    is_skippable: Any
    starts_with_sound: Any
    ad_length: Any
    top_content_only: Any
    has_guaranteed_price: Any

class GenerateProductMixIdeasResponse(proto.Message):
    product_allocation: Any

class ProductAllocation(proto.Message):
    plannable_product_code: Any
    budget_micros: Any

class GenerateReachForecastRequest(proto.Message):
    customer_id: Any
    currency_code: Any
    campaign_duration: Any
    cookie_frequency_cap: Any
    cookie_frequency_cap_setting: Any
    min_effective_frequency: Any
    targeting: Any
    planned_products: Any

class FrequencyCap(proto.Message):
    impressions: Any
    time_unit: Any

class Targeting(proto.Message):
    plannable_location_id: Any
    age_range: Any
    genders: Any
    devices: Any
    network: Any

class CampaignDuration(proto.Message):
    duration_in_days: Any

class PlannedProduct(proto.Message):
    plannable_product_code: Any
    budget_micros: Any

class GenerateReachForecastResponse(proto.Message):
    on_target_audience_metrics: Any
    reach_curve: Any

class ReachCurve(proto.Message):
    reach_forecasts: Any

class ReachForecast(proto.Message):
    cost_micros: Any
    forecast: Any
    planned_product_reach_forecasts: Any

class Forecast(proto.Message):
    on_target_reach: Any
    total_reach: Any
    on_target_impressions: Any
    total_impressions: Any
    viewable_impressions: Any

class PlannedProductReachForecast(proto.Message):
    plannable_product_code: Any
    cost_micros: Any
    planned_product_forecast: Any

class PlannedProductForecast(proto.Message):
    on_target_reach: Any
    total_reach: Any
    on_target_impressions: Any
    total_impressions: Any
    viewable_impressions: Any

class OnTargetAudienceMetrics(proto.Message):
    youtube_audience_size: Any
    census_audience_size: Any



from typing import Any

import proto

__protobuf__: Any

class AdTypeEnum(proto.Message):
    class AdType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TEXT_AD: int
        EXPANDED_TEXT_AD: int
        EXPANDED_DYNAMIC_SEARCH_AD: int
        HOTEL_AD: int
        SHOPPING_SMART_AD: int
        SHOPPING_PRODUCT_AD: int
        VIDEO_AD: int
        GMAIL_AD: int
        IMAGE_AD: int
        RESPONSIVE_SEARCH_AD: int
        LEGACY_RESPONSIVE_DISPLAY_AD: int
        APP_AD: int
        LEGACY_APP_INSTALL_AD: int
        RESPONSIVE_DISPLAY_AD: int
        LOCAL_AD: int
        HTML5_UPLOAD_AD: int
        DYNAMIC_HTML5_AD: int
        APP_ENGAGEMENT_AD: int
        SHOPPING_COMPARISON_LISTING_AD: int
        VIDEO_BUMPER_AD: int
        VIDEO_NON_SKIPPABLE_IN_STREAM_AD: int
        VIDEO_OUTSTREAM_AD: int
        VIDEO_TRUEVIEW_DISCOVERY_AD: int
        VIDEO_TRUEVIEW_IN_STREAM_AD: int
        VIDEO_RESPONSIVE_AD: int
        SMART_CAMPAIGN_AD: int
        CALL_AD: int



from typing import Any

import proto

__protobuf__: Any

class SharedCriterionErrorEnum(proto.Message):
    class SharedCriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class GoogleAdsFieldDataTypeEnum(proto.Message):
    class GoogleAdsFieldDataType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BOOLEAN: int
        DATE: int
        DOUBLE: int
        ENUM: int
        FLOAT: int
        INT32: int
        INT64: int
        MESSAGE: int
        RESOURCE_NAME: int
        STRING: int
        UINT64: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    customer_user_access_invitation as customer_user_access_invitation,
)

__protobuf__: Any

class GetCustomerUserAccessInvitationRequest(proto.Message):
    resource_name: Any

class MutateCustomerUserAccessInvitationRequest(proto.Message):
    customer_id: Any
    operation: Any

class CustomerUserAccessInvitationOperation(proto.Message):
    create: Any
    remove: Any

class MutateCustomerUserAccessInvitationResponse(proto.Message):
    result: Any

class MutateCustomerUserAccessInvitationResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class ConversionCustomVariableErrorEnum(proto.Message):
    class ConversionCustomVariableError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_NAME: int
        DUPLICATE_TAG: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    asset_types as asset_types,
    custom_parameter as custom_parameter,
    policy as policy,
)
from google.ads.googleads.v8.enums.types import (
    asset_type as asset_type,
    policy_approval_status as policy_approval_status,
    policy_review_status as policy_review_status,
)

__protobuf__: Any

class Asset(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    type_: Any
    final_urls: Any
    final_mobile_urls: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    final_url_suffix: Any
    policy_summary: Any
    youtube_video_asset: Any
    media_bundle_asset: Any
    image_asset: Any
    text_asset: Any
    lead_form_asset: Any
    book_on_google_asset: Any
    promotion_asset: Any
    callout_asset: Any
    structured_snippet_asset: Any
    sitelink_asset: Any

class AssetPolicySummary(proto.Message):
    policy_topic_entries: Any
    review_status: Any
    approval_status: Any



from typing import Any

import proto

__protobuf__: Any

class PriceExtensionPriceQualifierEnum(proto.Message):
    class PriceExtensionPriceQualifier(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FROM: int
        UP_TO: int
        AVERAGE: int



from typing import Any, Dict, Optional, Sequence, Tuple, Type, Union

from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    operation,
    retry as retries,
)
from google.auth import credentials

from google.ads.googleads.v7.resources.types import batch_job
from google.ads.googleads.v7.services.services.batch_job_service import pagers
from google.ads.googleads.v7.services.types import batch_job_service, google_ads_service

from .transports.base import BatchJobServiceTransport

class BatchJobServiceClientMeta(type):
    def get_transport_class(
        cls, label: str = ...
    ) -> Type[BatchJobServiceTransport]: ...

class BatchJobServiceClient(metaclass=BatchJobServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Any
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json: Any
    @property
    def transport(self) -> BatchJobServiceTransport: ...
    @staticmethod
    def ad_path(customer_id: str, ad_id: str) -> str: ...
    @staticmethod
    def parse_ad_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_path(customer_id: str, ad_group_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_ad_path(customer_id: str, ad_group_id: str, ad_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_ad_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_ad_label_path(
        customer_id: str, ad_group_id: str, ad_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_ad_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_asset_path(
        customer_id: str, ad_group_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_bid_modifier_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_bid_modifier_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_criterion_path(
        customer_id: str, ad_group_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_criterion_label_path(
        customer_id: str, ad_group_id: str, criterion_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_criterion_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_extension_setting_path(
        customer_id: str, ad_group_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_feed_path(customer_id: str, ad_group_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_ad_group_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_group_label_path(
        customer_id: str, ad_group_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_ad_group_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def ad_parameter_path(
        customer_id: str, ad_group_id: str, criterion_id: str, parameter_index: str
    ) -> str: ...
    @staticmethod
    def parse_ad_parameter_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def asset_path(customer_id: str, asset_id: str) -> str: ...
    @staticmethod
    def parse_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def batch_job_path(customer_id: str, batch_job_id: str) -> str: ...
    @staticmethod
    def parse_batch_job_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def bidding_strategy_path(customer_id: str, bidding_strategy_id: str) -> str: ...
    @staticmethod
    def parse_bidding_strategy_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_path(customer_id: str, campaign_id: str) -> str: ...
    @staticmethod
    def parse_campaign_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_asset_path(
        customer_id: str, campaign_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_bid_modifier_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_bid_modifier_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_budget_path(customer_id: str, campaign_budget_id: str) -> str: ...
    @staticmethod
    def parse_campaign_budget_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_criterion_path(
        customer_id: str, campaign_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_draft_path(
        customer_id: str, base_campaign_id: str, draft_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_draft_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_experiment_path(
        customer_id: str, campaign_experiment_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_experiment_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_extension_setting_path(
        customer_id: str, campaign_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_feed_path(customer_id: str, campaign_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_campaign_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_label_path(
        customer_id: str, campaign_id: str, label_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_shared_set_path(
        customer_id: str, campaign_id: str, shared_set_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_shared_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def conversion_action_path(customer_id: str, conversion_action_id: str) -> str: ...
    @staticmethod
    def parse_conversion_action_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def conversion_custom_variable_path(
        customer_id: str, conversion_custom_variable_id: str
    ) -> str: ...
    @staticmethod
    def parse_conversion_custom_variable_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_path(customer_id: str) -> str: ...
    @staticmethod
    def parse_customer_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_asset_path(
        customer_id: str, asset_id: str, field_type: str
    ) -> str: ...
    @staticmethod
    def parse_customer_asset_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_extension_setting_path(
        customer_id: str, extension_type: str
    ) -> str: ...
    @staticmethod
    def parse_customer_extension_setting_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_feed_path(customer_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_customer_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_label_path(customer_id: str, label_id: str) -> str: ...
    @staticmethod
    def parse_customer_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def customer_negative_criterion_path(
        customer_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_customer_negative_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def extension_feed_item_path(customer_id: str, feed_item_id: str) -> str: ...
    @staticmethod
    def parse_extension_feed_item_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_path(customer_id: str, feed_id: str) -> str: ...
    @staticmethod
    def parse_feed_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_path(customer_id: str, feed_id: str, feed_item_id: str) -> str: ...
    @staticmethod
    def parse_feed_item_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_set_path(
        customer_id: str, feed_id: str, feed_item_set_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_item_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_set_link_path(
        customer_id: str, feed_id: str, feed_item_set_id: str, feed_item_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_item_set_link_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_item_target_path(
        customer_id: str,
        feed_id: str,
        feed_item_id: str,
        feed_item_target_type: str,
        feed_item_target_id: str,
    ) -> str: ...
    @staticmethod
    def parse_feed_item_target_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def feed_mapping_path(
        customer_id: str, feed_id: str, feed_mapping_id: str
    ) -> str: ...
    @staticmethod
    def parse_feed_mapping_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def geo_target_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_geo_target_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_path(customer_id: str, keyword_plan_id: str) -> str: ...
    @staticmethod
    def parse_keyword_plan_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_ad_group_path(
        customer_id: str, keyword_plan_ad_group_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_ad_group_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_ad_group_keyword_path(
        customer_id: str, keyword_plan_ad_group_keyword_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_ad_group_keyword_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_campaign_path(
        customer_id: str, keyword_plan_campaign_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_campaign_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def keyword_plan_campaign_keyword_path(
        customer_id: str, keyword_plan_campaign_keyword_id: str
    ) -> str: ...
    @staticmethod
    def parse_keyword_plan_campaign_keyword_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def label_path(customer_id: str, label_id: str) -> str: ...
    @staticmethod
    def parse_label_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def language_constant_path(criterion_id: str) -> str: ...
    @staticmethod
    def parse_language_constant_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def media_file_path(customer_id: str, media_file_id: str) -> str: ...
    @staticmethod
    def parse_media_file_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def remarketing_action_path(
        customer_id: str, remarketing_action_id: str
    ) -> str: ...
    @staticmethod
    def parse_remarketing_action_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def shared_criterion_path(
        customer_id: str, shared_set_id: str, criterion_id: str
    ) -> str: ...
    @staticmethod
    def parse_shared_criterion_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def shared_set_path(customer_id: str, shared_set_id: str) -> str: ...
    @staticmethod
    def parse_shared_set_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def user_list_path(customer_id: str, user_list_id: str) -> str: ...
    @staticmethod
    def parse_user_list_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> Dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: Optional[credentials.Credentials] = ...,
        transport: Union[str, BatchJobServiceTransport, None] = ...,
        client_options: Optional[client_options_lib.ClientOptions] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    def mutate_batch_job(
        self,
        request: batch_job_service.MutateBatchJobRequest = ...,
        *,
        customer_id: str = ...,
        operation: batch_job_service.BatchJobOperation = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> batch_job_service.MutateBatchJobResponse: ...
    def get_batch_job(
        self,
        request: batch_job_service.GetBatchJobRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> batch_job.BatchJob: ...
    def list_batch_job_results(
        self,
        request: batch_job_service.ListBatchJobResultsRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> pagers.ListBatchJobResultsPager: ...
    def run_batch_job(
        self,
        request: batch_job_service.RunBatchJobRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> operation.Operation: ...
    def add_batch_job_operations(
        self,
        request: batch_job_service.AddBatchJobOperationsRequest = ...,
        *,
        resource_name: str = ...,
        sequence_token: str = ...,
        mutate_operations: Sequence[google_ads_service.MutateOperation] = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> batch_job_service.AddBatchJobOperationsResponse: ...



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2

from google.ads.googleads.v8.resources.types import (
    customer_client_link as customer_client_link,
)

__protobuf__: Any

class GetCustomerClientLinkRequest(proto.Message):
    resource_name: Any

class MutateCustomerClientLinkRequest(proto.Message):
    customer_id: Any
    operation: Any
    validate_only: Any

class CustomerClientLinkOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any

class MutateCustomerClientLinkResponse(proto.Message):
    result: Any

class MutateCustomerClientLinkResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    custom_parameter as custom_parameter,
    feed_common as feed_common,
)
from google.ads.googleads.v7.enums.types import (
    price_extension_price_qualifier as price_extension_price_qualifier,
    price_extension_price_unit as price_extension_price_unit,
    price_extension_type as price_extension_type,
    promotion_extension_discount_modifier as promotion_extension_discount_modifier,
    promotion_extension_occasion as promotion_extension_occasion,
)

__protobuf__: Any

class AppFeedItem(proto.Message):
    link_text: Any
    app_id: Any
    app_store: Any
    final_urls: Any
    final_mobile_urls: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    final_url_suffix: Any

class CallFeedItem(proto.Message):
    phone_number: Any
    country_code: Any
    call_tracking_enabled: Any
    call_conversion_action: Any
    call_conversion_tracking_disabled: Any
    call_conversion_reporting_state: Any

class CalloutFeedItem(proto.Message):
    callout_text: Any

class LocationFeedItem(proto.Message):
    business_name: Any
    address_line_1: Any
    address_line_2: Any
    city: Any
    province: Any
    postal_code: Any
    country_code: Any
    phone_number: Any

class AffiliateLocationFeedItem(proto.Message):
    business_name: Any
    address_line_1: Any
    address_line_2: Any
    city: Any
    province: Any
    postal_code: Any
    country_code: Any
    phone_number: Any
    chain_id: Any
    chain_name: Any

class TextMessageFeedItem(proto.Message):
    business_name: Any
    country_code: Any
    phone_number: Any
    text: Any
    extension_text: Any

class PriceFeedItem(proto.Message):
    type_: Any
    price_qualifier: Any
    tracking_url_template: Any
    language_code: Any
    price_offerings: Any
    final_url_suffix: Any

class PriceOffer(proto.Message):
    header: Any
    description: Any
    price: Any
    unit: Any
    final_urls: Any
    final_mobile_urls: Any

class PromotionFeedItem(proto.Message):
    promotion_target: Any
    discount_modifier: Any
    promotion_start_date: Any
    promotion_end_date: Any
    occasion: Any
    final_urls: Any
    final_mobile_urls: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    final_url_suffix: Any
    language_code: Any
    percent_off: Any
    money_amount_off: Any
    promotion_code: Any
    orders_over_amount: Any

class StructuredSnippetFeedItem(proto.Message):
    header: Any
    values: Any

class SitelinkFeedItem(proto.Message):
    link_text: Any
    line1: Any
    line2: Any
    final_urls: Any
    final_mobile_urls: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    final_url_suffix: Any

class HotelCalloutFeedItem(proto.Message):
    text: Any
    language_code: Any

class ImageFeedItem(proto.Message):
    image_asset: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import keyword_match_type as keyword_match_type

__protobuf__: Any

class KeywordPlanAdGroupKeyword(proto.Message):
    resource_name: Any
    keyword_plan_ad_group: Any
    id: Any
    text: Any
    match_type: Any
    cpc_bid_micros: Any
    negative: Any



from typing import Callable, TypeVar

import grpc

from google.ads.googleads import v7, v8
from google.ads.googleads.v7.services.types.google_ads_service import (
    SearchGoogleAdsStreamRequest,
)

from .interceptor import Interceptor

_Request = TypeVar(
    "_Request",
    v7.SearchGoogleAdsRequest,
    v7.SearchGoogleAdsStreamRequest,
    v8.SearchGoogleAdsRequest,
    v8.SearchGoogleAdsStreamRequest,
)
_Response = TypeVar("_Response")

class ExceptionInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    def __init__(self, api_version: str, use_proto_plus: bool = ...) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...



from typing import Any

import proto

__protobuf__: Any

class UserListTypeEnum(proto.Message):
    class UserListType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REMARKETING: int
        LOGICAL: int
        EXTERNAL_REMARKETING: int
        RULE_BASED: int
        SIMILAR: int
        CRM_BASED: int



from typing import Any

import proto

__protobuf__: Any

class ConversionValueRulePrimaryDimensionEnum(proto.Message):
    class ConversionValueRulePrimaryDimension(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NO_RULE_APPLIED: int
        ORIGINAL: int
        NEW_VS_RETURNING_USER: int
        GEO_LOCATION: int
        DEVICE: int
        AUDIENCE: int
        MULTIPLE: int



from typing import Any

import proto

__protobuf__: Any

class MonthOfYearEnum(proto.Message):
    class MonthOfYear(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        JANUARY: int
        FEBRUARY: int
        MARCH: int
        APRIL: int
        MAY: int
        JUNE: int
        JULY: int
        AUGUST: int
        SEPTEMBER: int
        OCTOBER: int
        NOVEMBER: int
        DECEMBER: int



from .base import (
    KeywordPlanAdGroupKeywordServiceTransport as KeywordPlanAdGroupKeywordServiceTransport,
)
from .grpc import (
    KeywordPlanAdGroupKeywordServiceGrpcTransport as KeywordPlanAdGroupKeywordServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class CampaignExperimentStatusEnum(proto.Message):
    class CampaignExperimentStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INITIALIZING: int
        INITIALIZATION_FAILED: int
        ENABLED: int
        GRADUATED: int
        REMOVED: int
        PROMOTING: int
        PROMOTION_FAILED: int
        PROMOTED: int
        ENDED_MANUALLY: int



from typing import Any

import proto

__protobuf__: Any

class RegionCodeErrorEnum(proto.Message):
    class RegionCodeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_REGION_CODE: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import custom_interest as custom_interest

__protobuf__: Any

class GetCustomInterestRequest(proto.Message):
    resource_name: Any

class MutateCustomInterestsRequest(proto.Message):
    customer_id: Any
    operations: Any
    validate_only: Any

class CustomInterestOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any

class MutateCustomInterestsResponse(proto.Message):
    results: Any

class MutateCustomInterestResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class SitelinkPlaceholderFieldEnum(proto.Message):
    class SitelinkPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TEXT: int
        LINE_1: int
        LINE_2: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        FINAL_URL_SUFFIX: int



from typing import Any

import proto

__protobuf__: Any

class QuotaErrorEnum(proto.Message):
    class QuotaError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RESOURCE_EXHAUSTED: int
        ACCESS_PROHIBITED: int
        RESOURCE_TEMPORARILY_EXHAUSTED: int



from typing import Any

import proto

__protobuf__: Any

class PreferredContentTypeEnum(proto.Message):
    class PreferredContentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YOUTUBE_TOP_CONTENT: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import google_ads_field as google_ads_field

__protobuf__: Any

class GetGoogleAdsFieldRequest(proto.Message):
    resource_name: Any

class SearchGoogleAdsFieldsRequest(proto.Message):
    query: Any
    page_token: Any
    page_size: Any

class SearchGoogleAdsFieldsResponse(proto.Message):
    @property
    def raw_page(self): ...
    results: Any
    next_page_token: Any
    total_results_count: Any



from typing import Any

import proto

__protobuf__: Any

class ExtensionTypeEnum(proto.Message):
    class ExtensionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NONE: int
        APP: int
        CALL: int
        CALLOUT: int
        MESSAGE: int
        PRICE: int
        PROMOTION: int
        SITELINK: int
        STRUCTURED_SNIPPET: int
        LOCATION: int
        AFFILIATE_LOCATION: int
        HOTEL_CALLOUT: int
        IMAGE: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    ad_customizer_placeholder_field as ad_customizer_placeholder_field,
    affiliate_location_placeholder_field as affiliate_location_placeholder_field,
    app_placeholder_field as app_placeholder_field,
    call_placeholder_field as call_placeholder_field,
    callout_placeholder_field as callout_placeholder_field,
    custom_placeholder_field as custom_placeholder_field,
    dsa_page_feed_criterion_field as dsa_page_feed_criterion_field,
    education_placeholder_field as education_placeholder_field,
    feed_mapping_criterion_type as feed_mapping_criterion_type,
    feed_mapping_status as feed_mapping_status,
    flight_placeholder_field as flight_placeholder_field,
    hotel_placeholder_field as hotel_placeholder_field,
    image_placeholder_field as image_placeholder_field,
    job_placeholder_field as job_placeholder_field,
    local_placeholder_field as local_placeholder_field,
    location_extension_targeting_criterion_field as location_extension_targeting_criterion_field,
    location_placeholder_field as location_placeholder_field,
    message_placeholder_field as message_placeholder_field,
    price_placeholder_field as price_placeholder_field,
    promotion_placeholder_field as promotion_placeholder_field,
    real_estate_placeholder_field as real_estate_placeholder_field,
    sitelink_placeholder_field as sitelink_placeholder_field,
    structured_snippet_placeholder_field as structured_snippet_placeholder_field,
    travel_placeholder_field as travel_placeholder_field,
)

__protobuf__: Any

class FeedMapping(proto.Message):
    resource_name: Any
    feed: Any
    attribute_field_mappings: Any
    status: Any
    placeholder_type: Any
    criterion_type: Any

class AttributeFieldMapping(proto.Message):
    feed_attribute_id: Any
    field_id: Any
    sitelink_field: Any
    call_field: Any
    app_field: Any
    location_field: Any
    affiliate_location_field: Any
    callout_field: Any
    structured_snippet_field: Any
    message_field: Any
    price_field: Any
    promotion_field: Any
    ad_customizer_field: Any
    dsa_page_feed_field: Any
    location_extension_targeting_field: Any
    education_field: Any
    flight_field: Any
    custom_field: Any
    hotel_field: Any
    real_estate_field: Any
    travel_field: Any
    local_field: Any
    job_field: Any
    image_field: Any



from typing import Any

import proto

__protobuf__: Any

class CampaignCriterionErrorEnum(proto.Message):
    class CampaignCriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONCRETE_TYPE_REQUIRED: int
        INVALID_PLACEMENT_URL: int
        CANNOT_EXCLUDE_CRITERIA_TYPE: int
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE: int
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA: int
        CANNOT_TARGET_AND_EXCLUDE: int
        TOO_MANY_OPERATIONS: int
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE: int
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL: int
        CANNOT_ADD_EXISTING_FIELD: int
        CANNOT_UPDATE_NEGATIVE_CRITERION: int
        CANNOT_SET_NEGATIVE_KEYWORD_THEME_CONSTANT_CRITERION: int
        INVALID_KEYWORD_THEME_CONSTANT: int
        MISSING_KEYWORD_THEME_CONSTANT_OR_FREE_FORM_KEYWORD_THEME: int
        CANNOT_TARGET_BOTH_PROXIMITY_AND_LOCATION_CRITERIA_FOR_SMART_CAMPAIGN: int
        CANNOT_TARGET_MULTIPLE_PROXIMITY_CRITERIA_FOR_SMART_CAMPAIGN: int



from typing import Any

import proto

__protobuf__: Any

class ChangeStatusErrorEnum(proto.Message):
    class ChangeStatusError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        START_DATE_TOO_OLD: int
        CHANGE_DATE_RANGE_INFINITE: int
        CHANGE_DATE_RANGE_NEGATIVE: int
        LIMIT_NOT_SPECIFIED: int
        INVALID_LIMIT_CLAUSE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    call_type as call_type,
    google_voice_call_status as google_voice_call_status,
)

__protobuf__: Any

class CallView(proto.Message):
    resource_name: Any
    caller_region_code: Any
    caller_area_code: Any
    call_duration_seconds: Any
    start_call_date_time: Any
    end_call_date_time: Any
    call_tracking_display_location: Any
    type_: Any
    call_status: Any



from typing import Any

import proto

__protobuf__: Any

class InvoiceTypeEnum(proto.Message):
    class InvoiceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CREDIT_MEMO: int
        INVOICE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    feed_item_set_string_filter_type as feed_item_set_string_filter_type,
)

__protobuf__: Any

class DynamicLocationSetFilter(proto.Message):
    labels: Any
    business_name_filter: Any

class BusinessNameFilter(proto.Message):
    business_name: Any
    filter_type: Any

class DynamicAffiliateLocationSetFilter(proto.Message):
    chain_ids: Any



from typing import Any

import proto

__protobuf__: Any

class InternalErrorEnum(proto.Message):
    class InternalError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INTERNAL_ERROR: int
        ERROR_CODE_NOT_PUBLISHED: int
        TRANSIENT_ERROR: int
        DEADLINE_EXCEEDED: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    shared_set_status as shared_set_status,
    shared_set_type as shared_set_type,
)

__protobuf__: Any

class SharedSet(proto.Message):
    resource_name: Any
    id: Any
    type_: Any
    name: Any
    status: Any
    member_count: Any
    reference_count: Any



from typing import Any

import proto

__protobuf__: Any

class TimeZoneErrorEnum(proto.Message):
    class TimeZoneError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_TIME_ZONE: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    matching_function_context_type as matching_function_context_type,
    matching_function_operator as matching_function_operator,
)

__protobuf__: Any

class MatchingFunction(proto.Message):
    function_string: Any
    operator: Any
    left_operands: Any
    right_operands: Any

class Operand(proto.Message):
    class ConstantOperand(proto.Message):
        string_value: Any
        long_value: Any
        boolean_value: Any
        double_value: Any
    class FeedAttributeOperand(proto.Message):
        feed_id: Any
        feed_attribute_id: Any
    class FunctionOperand(proto.Message):
        matching_function: Any
    class RequestContextOperand(proto.Message):
        context_type: Any
    constant_operand: Any
    feed_attribute_operand: Any
    function_operand: Any
    request_context_operand: Any



from typing import Any

import proto

__protobuf__: Any

class FeedItemValidationStatusEnum(proto.Message):
    class FeedItemValidationStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        INVALID: int
        VALID: int



from typing import Any

import proto

__protobuf__: Any

class QualityScoreBucketEnum(proto.Message):
    class QualityScoreBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BELOW_AVERAGE: int
        AVERAGE: int
        ABOVE_AVERAGE: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    keyword_plan_campaign_keyword as keyword_plan_campaign_keyword,
)

__protobuf__: Any

class GetKeywordPlanCampaignKeywordRequest(proto.Message):
    resource_name: Any

class MutateKeywordPlanCampaignKeywordsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class KeywordPlanCampaignKeywordOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateKeywordPlanCampaignKeywordsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateKeywordPlanCampaignKeywordResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class CustomerClient(proto.Message):
    resource_name: Any
    client_customer: Any
    hidden: Any
    level: Any
    time_zone: Any
    test_account: Any
    manager: Any
    descriptive_name: Any
    currency_code: Any
    id: Any
    applied_labels: Any



from typing import Any

import proto

__protobuf__: Any

class ConversionAdjustmentTypeEnum(proto.Message):
    class ConversionAdjustmentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RETRACTION: int
        RESTATEMENT: int



from typing import Any

import proto

__protobuf__: Any

class SystemManagedResourceSourceEnum(proto.Message):
    class SystemManagedResourceSource(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_VARIATIONS: int



from typing import Any

import proto

__protobuf__: Any

class ProductTypeLevelEnum(proto.Message):
    class ProductTypeLevel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LEVEL1: int
        LEVEL2: int
        LEVEL3: int
        LEVEL4: int
        LEVEL5: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import customer
from google.ads.googleads.v7.services.types import customer_service

class CustomerServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_customer(
        self,
    ) -> typing.Callable[[customer_service.GetCustomerRequest], customer.Customer]: ...
    @property
    def mutate_customer(
        self,
    ) -> typing.Callable[
        [customer_service.MutateCustomerRequest],
        customer_service.MutateCustomerResponse,
    ]: ...
    @property
    def list_accessible_customers(
        self,
    ) -> typing.Callable[
        [customer_service.ListAccessibleCustomersRequest],
        customer_service.ListAccessibleCustomersResponse,
    ]: ...
    @property
    def create_customer_client(
        self,
    ) -> typing.Callable[
        [customer_service.CreateCustomerClientRequest],
        customer_service.CreateCustomerClientResponse,
    ]: ...



from .base import (
    DetailedDemographicServiceTransport as DetailedDemographicServiceTransport,
)
from .grpc import (
    DetailedDemographicServiceGrpcTransport as DetailedDemographicServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ServedAssetFieldTypeEnum(proto.Message):
    class ServedAssetFieldType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HEADLINE_1: int
        HEADLINE_2: int
        HEADLINE_3: int
        DESCRIPTION_1: int
        DESCRIPTION_2: int



from typing import Any

import proto

__protobuf__: Any

class DomainCategory(proto.Message):
    resource_name: Any
    campaign: Any
    category: Any
    language_code: Any
    domain: Any
    coverage_fraction: Any
    category_rank: Any
    has_children: Any
    recommended_cpc_bid_micros: Any



from typing import Any

import proto

__protobuf__: Any

class AdCustomizerErrorEnum(proto.Message):
    class AdCustomizerError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        COUNTDOWN_INVALID_DATE_FORMAT: int
        COUNTDOWN_DATE_IN_PAST: int
        COUNTDOWN_INVALID_LOCALE: int
        COUNTDOWN_INVALID_START_DAYS_BEFORE: int
        UNKNOWN_USER_LIST: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1, operations_v1
from google.auth import credentials as ga_credentials
from google.longrunning import operations_pb2

from google.ads.googleads.v8.resources.types import batch_job
from google.ads.googleads.v8.services.types import batch_job_service

class BatchJobServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def operations_client(self) -> operations_v1.OperationsClient: ...
    @property
    def mutate_batch_job(
        self,
    ) -> typing.Callable[
        [batch_job_service.MutateBatchJobRequest],
        batch_job_service.MutateBatchJobResponse,
    ]: ...
    @property
    def get_batch_job(
        self,
    ) -> typing.Callable[
        [batch_job_service.GetBatchJobRequest], batch_job.BatchJob
    ]: ...
    @property
    def list_batch_job_results(
        self,
    ) -> typing.Callable[
        [batch_job_service.ListBatchJobResultsRequest],
        batch_job_service.ListBatchJobResultsResponse,
    ]: ...
    @property
    def run_batch_job(
        self,
    ) -> typing.Callable[
        [batch_job_service.RunBatchJobRequest], operations_pb2.Operation
    ]: ...
    @property
    def add_batch_job_operations(
        self,
    ) -> typing.Callable[
        [batch_job_service.AddBatchJobOperationsRequest],
        batch_job_service.AddBatchJobOperationsResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class GeoTargetingRestrictionEnum(proto.Message):
    class GeoTargetingRestriction(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOCATION_OF_PRESENCE: int



from typing import Any

import proto

__protobuf__: Any

class NotEmptyErrorEnum(proto.Message):
    class NotEmptyError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EMPTY_LIST: int



from typing import Any

import proto

__protobuf__: Any

class ExtensionSettingErrorEnum(proto.Message):
    class ExtensionSettingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXTENSIONS_REQUIRED: int
        FEED_TYPE_EXTENSION_TYPE_MISMATCH: int
        INVALID_FEED_TYPE: int
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING: int
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE: int
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION: int
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE: int
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE: int
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE: int
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS: int
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS: int
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS: int
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        VALUE_OUT_OF_RANGE: int
        CANNOT_SET_FIELD_WITH_FINAL_URLS: int
        FINAL_URLS_NOT_SET: int
        INVALID_PHONE_NUMBER: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_COUNTRY_CODE: int
        INVALID_CALL_CONVERSION_TYPE_ID: int
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        INVALID_APP_ID: int
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE: int
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int
        MISSING_FIELD: int
        INCONSISTENT_CURRENCY_CODES: int
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS: int
        UNSUPPORTED_VALUE: int
        INVALID_DEVICE_PREFERENCE: int
        INVALID_SCHEDULE_END: int
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int
        OVERLAPPING_SCHEDULES_NOT_ALLOWED: int
        SCHEDULE_END_NOT_AFTER_START: int
        TOO_MANY_SCHEDULES_PER_DAY: int
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT: int
        INVALID_SNIPPETS_HEADER: int
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int
        CAMPAIGN_TARGETING_MISMATCH: int
        CANNOT_OPERATE_ON_REMOVED_FEED: int
        EXTENSION_TYPE_REQUIRED: int
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION: int
        START_DATE_AFTER_END_DATE: int
        INVALID_PRICE_FORMAT: int
        PROMOTION_INVALID_TIME: int
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        INVALID_LANGUAGE_CODE: int
        UNSUPPORTED_LANGUAGE: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        EXTENSION_SETTING_UPDATE_IS_A_NOOP: int
        DISALLOWED_TEXT: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    feed_item_set_link as feed_item_set_link,
)

__protobuf__: Any

class GetFeedItemSetLinkRequest(proto.Message):
    resource_name: Any

class MutateFeedItemSetLinksRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class FeedItemSetLinkOperation(proto.Message):
    create: Any
    remove: Any

class MutateFeedItemSetLinksResponse(proto.Message):
    results: Any

class MutateFeedItemSetLinkResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class PolicyTopicEntryTypeEnum(proto.Message):
    class PolicyTopicEntryType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PROHIBITED: int
        LIMITED: int
        FULLY_LIMITED: int
        DESCRIPTIVE: int
        BROADENING: int
        AREA_OF_INTEREST_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class BatchJobErrorEnum(proto.Message):
    class BatchJobError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING: int
        EMPTY_OPERATIONS: int
        INVALID_SEQUENCE_TOKEN: int
        RESULTS_NOT_READY: int
        INVALID_PAGE_SIZE: int
        CAN_ONLY_REMOVE_PENDING_JOB: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    ad_group_criterion_label as ad_group_criterion_label,
)

__protobuf__: Any

class GetAdGroupCriterionLabelRequest(proto.Message):
    resource_name: Any

class MutateAdGroupCriterionLabelsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class AdGroupCriterionLabelOperation(proto.Message):
    create: Any
    remove: Any

class MutateAdGroupCriterionLabelsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateAdGroupCriterionLabelResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

from google.ads.googleads.v8.common.types import policy as policy
from google.ads.googleads.v8.enums.types import (
    policy_approval_status as policy_approval_status,
    policy_review_status as policy_review_status,
)

__protobuf__: Any

class AdAssetPolicySummary(proto.Message):
    policy_topic_entries: Any
    review_status: Any
    approval_status: Any



from typing import Any

import proto

__protobuf__: Any

class EnumErrorEnum(proto.Message):
    class EnumError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ENUM_VALUE_NOT_PERMITTED: int



from typing import Any

import proto

__protobuf__: Any

class OptimizationGoalTypeEnum(proto.Message):
    class OptimizationGoalType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CALL_CLICKS: int
        DRIVING_DIRECTIONS: int



from typing import Any

import proto

__protobuf__: Any

class DayOfWeekEnum(proto.Message):
    class DayOfWeek(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MONDAY: int
        TUESDAY: int
        WEDNESDAY: int
        THURSDAY: int
        FRIDAY: int
        SATURDAY: int
        SUNDAY: int



from typing import Any, Callable, Iterable, Sequence, Tuple

from google.ads.googleads.v8.services.types import (
    batch_job_service as batch_job_service,
)

class ListBatchJobResultsPager:
    def __init__(
        self,
        method: Callable[..., batch_job_service.ListBatchJobResultsResponse],
        request: batch_job_service.ListBatchJobResultsRequest,
        response: batch_job_service.ListBatchJobResultsResponse,
        metadata: Sequence[Tuple[str, str]] = ...,
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(self) -> Iterable[batch_job_service.ListBatchJobResultsResponse]: ...
    def __iter__(self) -> Iterable[batch_job_service.BatchJobResult]: ...



from typing import Any

import proto

__protobuf__: Any

class LeadFormFieldUserInputTypeEnum(proto.Message):
    class LeadFormFieldUserInputType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FULL_NAME: int
        GIVEN_NAME: int
        FAMILY_NAME: int
        EMAIL: int
        PHONE_NUMBER: int
        POSTAL_CODE: int
        CITY: int
        REGION: int
        COUNTRY: int
        WORK_EMAIL: int
        COMPANY_NAME: int
        WORK_PHONE: int
        JOB_TITLE: int
        VEHICLE_MODEL: int
        VEHICLE_TYPE: int
        PREFERRED_DEALERSHIP: int
        VEHICLE_PURCHASE_TIMELINE: int
        VEHICLE_OWNERSHIP: int
        VEHICLE_PAYMENT_TYPE: int
        VEHICLE_CONDITION: int
        COMPANY_SIZE: int
        ANNUAL_SALES: int
        YEARS_IN_BUSINESS: int
        JOB_DEPARTMENT: int
        JOB_ROLE: int
        EDUCATION_PROGRAM: int
        EDUCATION_COURSE: int
        PRODUCT: int
        SERVICE: int
        OFFER: int
        CATEGORY: int
        PREFERRED_CONTACT_METHOD: int
        PREFERRED_LOCATION: int
        PREFERRED_CONTACT_TIME: int
        PURCHASE_TIMELINE: int
        YEARS_OF_EXPERIENCE: int
        JOB_INDUSTRY: int
        LEVEL_OF_EDUCATION: int
        PROPERTY_TYPE: int
        REALTOR_HELP_GOAL: int
        PROPERTY_COMMUNITY: int
        PRICE_RANGE: int
        NUMBER_OF_BEDROOMS: int
        FURNISHED_PROPERTY: int
        PETS_ALLOWED_PROPERTY: int
        NEXT_PLANNED_PURCHASE: int
        EVENT_SIGNUP_INTEREST: int
        PREFERRED_SHOPPING_PLACES: int
        FAVORITE_BRAND: int
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE: int
        EVENT_BOOKING_INTEREST: int
        DESTINATION_COUNTRY: int
        DESTINATION_CITY: int
        DEPARTURE_COUNTRY: int
        DEPARTURE_CITY: int
        DEPARTURE_DATE: int
        RETURN_DATE: int
        NUMBER_OF_TRAVELERS: int
        TRAVEL_BUDGET: int
        TRAVEL_ACCOMMODATION: int



from typing import Any

import proto

__protobuf__: Any

class CriterionCategoryChannelAvailabilityModeEnum(proto.Message):
    class CriterionCategoryChannelAvailabilityMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ALL_CHANNELS: int
        CHANNEL_TYPE_AND_ALL_SUBTYPES: int
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES: int



from typing import Any

import proto

__protobuf__: Any

class LeadFormDesiredIntentEnum(proto.Message):
    class LeadFormDesiredIntent(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOW_INTENT: int
        HIGH_INTENT: int



from typing import Any

import proto

__protobuf__: Any

class VanityPharmaTextEnum(proto.Message):
    class VanityPharmaText(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRESCRIPTION_TREATMENT_WEBSITE_EN: int
        PRESCRIPTION_TREATMENT_WEBSITE_ES: int
        PRESCRIPTION_DEVICE_WEBSITE_EN: int
        PRESCRIPTION_DEVICE_WEBSITE_ES: int
        MEDICAL_DEVICE_WEBSITE_EN: int
        MEDICAL_DEVICE_WEBSITE_ES: int
        PREVENTATIVE_TREATMENT_WEBSITE_EN: int
        PREVENTATIVE_TREATMENT_WEBSITE_ES: int
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN: int
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES: int
        PRESCRIPTION_VACCINE_WEBSITE_EN: int
        PRESCRIPTION_VACCINE_WEBSITE_ES: int



from .base import (
    ExpandedLandingPageViewServiceTransport as ExpandedLandingPageViewServiceTransport,
)
from .grpc import (
    ExpandedLandingPageViewServiceGrpcTransport as ExpandedLandingPageViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class WebpageConditionOperandEnum(proto.Message):
    class WebpageConditionOperand(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        URL: int
        CATEGORY: int
        PAGE_TITLE: int
        PAGE_CONTENT: int
        CUSTOM_LABEL: int



from typing import Any

import proto

__protobuf__: Any

class TrackingCodeTypeEnum(proto.Message):
    class TrackingCodeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        WEBPAGE: int
        WEBPAGE_ONCLICK: int
        CLICK_TO_CALL: int
        WEBSITE_CALL: int



from typing import Any

import proto

__protobuf__: Any

class CustomPlaceholderFieldEnum(proto.Message):
    class CustomPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ID: int
        ID2: int
        ITEM_TITLE: int
        ITEM_SUBTITLE: int
        ITEM_DESCRIPTION: int
        ITEM_ADDRESS: int
        PRICE: int
        FORMATTED_PRICE: int
        SALE_PRICE: int
        FORMATTED_SALE_PRICE: int
        IMAGE_URL: int
        ITEM_CATEGORY: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        CONTEXTUAL_KEYWORDS: int
        ANDROID_APP_LINK: int
        SIMILAR_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int



from typing import Any

import proto

__protobuf__: Any

class NegativeGeoTargetTypeEnum(proto.Message):
    class NegativeGeoTargetType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRESENCE_OR_INTEREST: int
        PRESENCE: int



from .base import (
    PaidOrganicSearchTermViewServiceTransport as PaidOrganicSearchTermViewServiceTransport,
)
from .grpc import (
    PaidOrganicSearchTermViewServiceGrpcTransport as PaidOrganicSearchTermViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class AdErrorEnum(proto.Message):
    class AdError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE: int
        APPROXIMATELY_TOO_LONG: int
        APPROXIMATELY_TOO_SHORT: int
        BAD_SNIPPET: int
        CANNOT_MODIFY_AD: int
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET: int
        CANNOT_SET_FIELD: int
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET: int
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING: int
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE: int
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING: int
        CANNOT_SET_URL: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        CANNOT_SET_WITH_FINAL_URLS: int
        CANNOT_SET_WITH_URL_DATA: int
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR: int
        CUSTOMER_NOT_APPROVED_MOBILEADS: int
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS: int
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS: int
        CUSTOMER_NOT_ELIGIBLE: int
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL: int
        DIMENSION_ALREADY_IN_UNION: int
        DIMENSION_MUST_BE_SET: int
        DIMENSION_NOT_IN_UNION: int
        DISPLAY_URL_CANNOT_BE_SPECIFIED: int
        DOMESTIC_PHONE_NUMBER_FORMAT: int
        EMERGENCY_PHONE_NUMBER: int
        EMPTY_FIELD: int
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID: int
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH: int
        ILLEGAL_AD_CUSTOMIZER_TAG_USE: int
        ILLEGAL_TAG_USE: int
        INCONSISTENT_DIMENSIONS: int
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION: int
        INCORRECT_LENGTH: int
        INELIGIBLE_FOR_UPGRADE: int
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET: int
        INVALID_AD_TYPE: int
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE: int
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT: int
        INVALID_CALL_TO_ACTION_TEXT: int
        INVALID_CHARACTER_FOR_URL: int
        INVALID_COUNTRY_CODE: int
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int
        INVALID_INPUT: int
        INVALID_MARKUP_LANGUAGE: int
        INVALID_MOBILE_CARRIER: int
        INVALID_MOBILE_CARRIER_TARGET: int
        INVALID_NUMBER_OF_ELEMENTS: int
        INVALID_PHONE_NUMBER_FORMAT: int
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID: int
        INVALID_TEMPLATE_DATA: int
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE: int
        INVALID_TEMPLATE_ID: int
        LINE_TOO_WIDE: int
        MISSING_AD_CUSTOMIZER_MAPPING: int
        MISSING_ADDRESS_COMPONENT: int
        MISSING_ADVERTISEMENT_NAME: int
        MISSING_BUSINESS_NAME: int
        MISSING_DESCRIPTION1: int
        MISSING_DESCRIPTION2: int
        MISSING_DESTINATION_URL_TAG: int
        MISSING_LANDING_PAGE_URL_TAG: int
        MISSING_DIMENSION: int
        MISSING_DISPLAY_URL: int
        MISSING_HEADLINE: int
        MISSING_HEIGHT: int
        MISSING_IMAGE: int
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS: int
        MISSING_MARKUP_LANGUAGES: int
        MISSING_MOBILE_CARRIER: int
        MISSING_PHONE: int
        MISSING_REQUIRED_TEMPLATE_FIELDS: int
        MISSING_TEMPLATE_FIELD_VALUE: int
        MISSING_TEXT: int
        MISSING_VISIBLE_URL: int
        MISSING_WIDTH: int
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED: int
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD: int
        TOO_LONG: int
        TOO_SHORT: int
        UNION_DIMENSIONS_CANNOT_CHANGE: int
        UNKNOWN_ADDRESS_COMPONENT: int
        UNKNOWN_FIELD_NAME: int
        UNKNOWN_UNIQUE_NAME: int
        UNSUPPORTED_DIMENSIONS: int
        URL_INVALID_SCHEME: int
        URL_INVALID_TOP_LEVEL_DOMAIN: int
        URL_MALFORMED: int
        URL_NO_HOST: int
        URL_NOT_EQUIVALENT: int
        URL_HOST_NAME_TOO_LONG: int
        URL_NO_SCHEME: int
        URL_NO_TOP_LEVEL_DOMAIN: int
        URL_PATH_NOT_ALLOWED: int
        URL_PORT_NOT_ALLOWED: int
        URL_QUERY_NOT_ALLOWED: int
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE: int
        INCONSISTENT_EXPANDABLE_SETTINGS: int
        INVALID_FORMAT: int
        INVALID_FIELD_TEXT: int
        ELEMENT_NOT_PRESENT: int
        IMAGE_ERROR: int
        VALUE_NOT_IN_RANGE: int
        FIELD_NOT_PRESENT: int
        ADDRESS_NOT_COMPLETE: int
        ADDRESS_INVALID: int
        VIDEO_RETRIEVAL_ERROR: int
        AUDIO_ERROR: int
        INVALID_YOUTUBE_DISPLAY_URL: int
        TOO_MANY_PRODUCT_IMAGES: int
        TOO_MANY_PRODUCT_VIDEOS: int
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_CALL_CONVERSION_TYPE_ID: int
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID: int
        CANNOT_SET_PATH2_WITHOUT_PATH1: int
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME: int
        INCOMPATIBLE_WITH_RESTRICTION_TYPE: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        MISSING_IMAGE_OR_MEDIA_BUNDLE: int
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN: int
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE: int
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE: int
        PLACEHOLDER_DEFAULT_VALUE_MISSING: int
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE: int
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT: int
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION: int
        TOO_MANY_AD_CUSTOMIZERS: int
        INVALID_AD_CUSTOMIZER_FORMAT: int
        NESTED_AD_CUSTOMIZER_SYNTAX: int
        UNSUPPORTED_AD_CUSTOMIZER_SYNTAX: int
        UNPAIRED_BRACE_IN_AD_CUSTOMIZER_TAG: int
        MORE_THAN_ONE_COUNTDOWN_TAG_TYPE_EXISTS: int
        DATE_TIME_IN_COUNTDOWN_TAG_IS_INVALID: int
        DATE_TIME_IN_COUNTDOWN_TAG_IS_PAST: int
        UNRECOGNIZED_AD_CUSTOMIZER_TAG_FOUND: int
        STORE_MISMATCH: int
        MISSING_REQUIRED_IMAGE_ASPECT_RATIO: int



from .base import (
    ShoppingPerformanceViewServiceTransport as ShoppingPerformanceViewServiceTransport,
)
from .grpc import (
    ShoppingPerformanceViewServiceGrpcTransport as ShoppingPerformanceViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class PolicyFindingErrorEnum(proto.Message):
    class PolicyFindingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        POLICY_FINDING: int
        POLICY_TOPIC_NOT_FOUND: int



from typing import Any

import proto

__protobuf__: Any

class AssetPerformanceLabelEnum(proto.Message):
    class AssetPerformanceLabel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        LEARNING: int
        LOW: int
        GOOD: int
        BEST: int



from typing import Any

import proto

__protobuf__: Any

class FlightPlaceholderFieldEnum(proto.Message):
    class FlightPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DESTINATION_ID: int
        ORIGIN_ID: int
        FLIGHT_DESCRIPTION: int
        ORIGIN_NAME: int
        DESTINATION_NAME: int
        FLIGHT_PRICE: int
        FORMATTED_PRICE: int
        FLIGHT_SALE_PRICE: int
        FORMATTED_SALE_PRICE: int
        IMAGE_URL: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        ANDROID_APP_LINK: int
        SIMILAR_DESTINATION_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int
